#!/usr/bin/env python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Check imagemagic is installed."""

import logging
import apt

PKG_NAME = 'imagemagick'


def main():
    """Check imagemagic is installed."""
    logging.info('Getting apt cache')
    cache = apt.cache.Cache()

    logging.info('Checking if {!r} is installed...'.format(PKG_NAME))
    if not PKG_NAME in cache:
        raise AssertionError('{!r} not found'.format(PKG_NAME))

    pkg = cache[PKG_NAME]
    if not pkg.is_installed:
        raise AssertionError('{!r} is not installed'.format(PKG_NAME))
    logging.info('{!r} is installed'.format(PKG_NAME))

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    main()
