#!/usr/bin/env python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Startup application list is empty."""

import logging
import unittest
import subprocess
import time
import os
import tempfile


class EmptyStartupAppTest(unittest.TestCase):
    APP_BINARY = 'gnome-session-properties'
    WINDOW_NAME = 'Startup Applications Preferences'
    IMAGE_SIZE = '400x300'

    def test_empty_startup_app_test(self):
        """Startup application list is empty."""
        logging.info('Launching {!r}...'.format(self.APP_BINARY))
        app_process = subprocess.Popen(self.APP_BINARY)
        time.sleep(1)  # Wait for the application window to be displayed

        try:
            logging.info('Creating temporary directory...')
            temp_dir = tempfile.mkdtemp(prefix='empty_startup_app_test_')

            xwd_image = os.path.join(temp_dir, 'capture.xwd')
            png_image = os.path.join(temp_dir, 'capture.png')
            blank_image = os.path.join(temp_dir, 'blank.png')
            diff_image = os.path.join(temp_dir, 'diff.png')

            logging.info('Taking window screenshot...')
            cmd = ['xwd', '-name', self.WINDOW_NAME, '-out', xwd_image]
            subprocess.check_call(cmd)

            # Get rid of window decoration that might change depending on the
            # theme
            logging.info('Cropping application list from window screenshot...')
            cmd = ['convert', '-crop', self.IMAGE_SIZE + '+30+55',
                   '-monochrome', xwd_image, png_image]
            subprocess.check_call(cmd)

            logging.info('Generating blank image of the same size...')
            cmd = ['convert', '-size', self.IMAGE_SIZE,
                   'xc:white', blank_image]
            subprocess.check_call(cmd)

            logging.info('Comparing captured and blank images...')
            # Note: compare outputs to stderr
            cmd = ['compare', '-metric', 'AE',
                   png_image, blank_image, diff_image]
            output = (subprocess.Popen(cmd, stderr=subprocess.PIPE)
                      .communicate()[1])
            self.assertEqual(output.strip(), '0',
                             "Startup application list doesn't seem empty")
        finally:
            logging.info('Closing {!r}...'.format(self.APP_BINARY))
            app_process.kill()

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
