#!/usr/bin/env python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Test encrypted home content.

Requires root access to access these links

If it is not mounted there are 2 symlinks:
Access-Your-Private-Data.desktop ->
    /usr/share/ecryptfs-utils/ecryptfs-mount-private.desktop
README.txt -> /usr/share/ecryptfs-utils/ecryptfs-mount-private.txt

"""


import logging
import unittest
import os


class EncryptedHomeContentTest(unittest.TestCase):
    USER = 'utah'
    HOMEDIR = os.path.join('/home', USER)
    ACCESS_DESKTOP = os.path.join(HOMEDIR,
                                  'Access-Your-Private-Data.desktop')
    README_TXT = os.path.join(HOMEDIR, 'README.txt')
    PRIVATE_DIR = os.path.join(HOMEDIR, '.Private')

    def test_encrypted_home_content(self):
        """Test encrypted home content."""
        logging.info('Checking that home directory ({!r}) exists'
                     .format(self.HOMEDIR))
        self.assertTrue(os.path.exists(self.HOMEDIR),
                        "Home directory ({!r}) doesn't exist"
                        .format(self.HOMEDIR))

        if not os.path.ismount(self.HOMEDIR):
            logging.info('Home directory ({!r}) is mounted'
                         .format(self.HOMEDIR))
            are_links = (os.path.islink(self.ACCESS_DESKTOP) and
                         os.path.islink(self.README_TXT))
            self.assertTrue(are_links,
                            'Expected symlinks not found:\n- {}\n- {}'
                            .format(self.ACCESS_DESKTOP, self.README_TXT))
        else:
            logging.info('Home directory ({!r}) is *not* mounted'
                         .format(self.HOMEDIR))
            self.assertTrue(os.path.islink(self.PRIVATE_DIR),
                            'Expected symlink not found:\n- {}'
                            .format(self.PRIVATE_DIR))
        logging.info('Expected links found')

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
