#!/usr/bin/env python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Test permissions of encrypted home directory.

Must be owned by ubuntu and mode set to 0500 if not mounted or 0700 if mounted

"""

import logging
import unittest
import os
import stat


class EncryptedHomePermissionsTest(unittest.TestCase):
    USER = 'utah'
    HOMEDIR = os.path.join('/home', USER)

    def test_encrypted_home_permissions(self):
        """Test permissions of encrypted home directory."""
        logging.info('Checking that home directory ({!r}) exists'
                     .format(self.HOMEDIR))
        self.assertTrue(os.path.exists(self.HOMEDIR),
                        "Home directory ({!r}) doesn't exist"
                        .format(self.HOMEDIR))

        logging.info('Getting home directory permissions...')
        permissions = stat.S_IMODE(os.stat(self.HOMEDIR).st_mode)
        if not os.path.ismount(self.HOMEDIR):
            logging.info('Home directory is mounted')
            expected_permissions = 0500
        else:
            logging.info('Home directory is *not* mounted')
            expected_permissions = 0700
        self.assertEqual(
            permissions, expected_permissions,
            'Home directory permissions ({:o}) should be set to {:o}'
            .format(permissions, expected_permissions))
        logging.info('Permissions ({:o}) are correctly set'
                     .format(permissions))

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
