#!/usr/bin/env python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Machine ID doesn't exist on the rofs."""

import logging
import os
import unittest


class NoRofsMachineId(unittest.TestCase):
    MACHINE_ID_FILE = 'var/lib/dbus/machine-id'
    ROFS_DIR = '/rofs'

    def test_no_rofs_machine_id(self):
        """Machine ID doesn't exist on the rofs."""
        rofs_machine_id = os.path.join(self.ROFS_DIR, self.MACHINE_ID_FILE)
        logging.info("Checking that machine id file under {} ({}) "
                     "doesn't exist"
                     .format(self.ROFS_DIR, rofs_machine_id))
        self.assertFalse(os.path.exists(rofs_machine_id),
                         'Machine ID file ({}) exists'.format(rofs_machine_id))

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
