#!/usr/bin/python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Check that kernel ring buffer doesn't contain any out of memory error."""

import logging
import unittest
import subprocess
import re


class OutOfMemoryTest(unittest.TestCase):
    OOM_REGEX = re.compile(r'^.*oom-killer.*$', re.MULTILINE)

    def test_out_of_memory(self):
        """Check that there isn't any out of memory error."""
        logging.info('Reading kernel ring buffer...')
        output = subprocess.check_output('dmesg')
        logging.info('Looking for out of memory pattern...')
        matches = self.OOM_REGEX.findall(output)
        logging.info('Pattern found {} times'.format(len(matches)))
        for match in matches:
            logging.debug(match)
        self.assertEqual(len(matches), 0,
                         'Out of memory pattern found {} times (see above)'
                         .format(len(matches)))


if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
