#!/usr/bin/python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Temporary file can be written."""

import logging
import os.path
import unittest


class ReadWriteTest(unittest.TestCase):
    FILENAME = os.path.join('/tmp', 'a')
    CONTENTS = 'a'

    def test_read_write(self):
        """Temporary file can be written."""
        logging.info('Opening file {!r} for writing...'.format(self.FILENAME))
        f = open(self.FILENAME, 'w')

        logging.info('Checking if the file opened...')
        self.assertNotEqual(f, None)

        logging.info('Writing {!r} to {!r}...'
                     .format(self.CONTENTS, self.FILENAME))
        self.assertEqual(f.write('a'), None)

        logging.info('Closing file...')
        self.assertEqual(f.close(), None)

        logging.info('Opening file {!r} for reading...'.format(self.FILENAME))
        f = open(self.FILENAME)

        logging.info('Checking if the file opened...')
        self.assertNotEqual(f, None)

        logging.info('Reading file contents...'.format(self.FILENAME))
        self.assertEqual(f.read(), self.CONTENTS)

        logging.info("Closing file...")
        self.assertEqual(f.close(), None)

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
