#!/usr/bin/python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Check that disk size is the expected one.

Note: This test case assumes expected size (5GB) matches the physical size or
the size assigned to the virtual machine being tested for the expected device.

"""

import logging
import unittest
import subprocess


class TotalDiskTest(unittest.TestCase):
    DEVICE = '/dev/vda'
    EXPECTED_SIZE = 5242880

    def test_total_disk(self):
        """Check that disk size is the expected one."""
        logging.info('Getting disk size for {}'.format(self.DEVICE))
        command = ['sfdisk', '--show-size', self.DEVICE]
        size = int(subprocess.check_output(command))
        logging.info('Disk size is: {}'.format(size))
        self.assertEqual(size, self.EXPECTED_SIZE,
                         'Expected disk size ({}), '
                         'does *not* match expected value: {}'
                         .format(size, self.EXPECTED_SIZE))

        logging.info('Disk size matches the expected value: {}'
                     .format(self.EXPECTED_SIZE))

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
