#!/usr/bin/python
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Check that total memory is in the expected range.

Note: This test case assumes the upper bound matches the physical memory or the
memory assigned to the virtual machine being tested.

"""

import logging
import unittest
import subprocess


class TotalMemTest(unittest.TestCase):
    UPPER_BOUND = 512
    LOWER_BOUND = UPPER_BOUND - 40

    def test_total_mem(self):
        """Check that total memory is in the expected range."""
        logging.info('Getting total memory...')
        stdout = subprocess.check_output(['free', '-m'])
        lines = stdout.splitlines()
        mem_line = lines[1].split()
        self.assertEqual(mem_line[0], 'Mem:',
                         'Failed to parse memory line: {}'.format(mem_line))

        total_mem = int(mem_line[1])
        logging.info('Total memory is: {}'.format(total_mem))

        self.assertTrue(
            self.LOWER_BOUND < total_mem < self.UPPER_BOUND,
            "Total memory ({} MB) is *not* in the expected range: "
            "({} MB - {} MB)"
            .format(total_mem, self.LOWER_BOUND, self.UPPER_BOUND))

        logging.info("Total memory ({} MB) is in the expected range: "
                     "({} MB - {} MB)"
                     .format(total_mem, self.LOWER_BOUND, self.UPPER_BOUND))

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
